Vhea

Struct Vhea 

pub struct Vhea<'a> {
    data: FontData<'a>,
}
The vhea Vertical Header Table

Fields

data: FontData<'a>

Implementations

Source

impl<'a> Vhea<'a>

pub const MIN_SIZE: usize

pub fn resolve_offset<O: Offset, R: FontRead<'a>>( &self, offset: O, ) -> Result<R, ReadError>

Resolve the provided offset from the start of this table.

pub fn offset_data(&self) -> FontData<'a>

Return a reference to this table’s raw data.

We use this in the compile crate to resolve offsets.

pub fn shape(&self) -> &Self

👎Deprecated: just use the base type directly

Return a reference to the table’s ‘Shape’ struct.

This is a low level implementation detail, but it can be useful in some cases where you want to know things about a table’s layout, such as the byte offsets of specific fields.

pub fn version(&self) -> Version16Dot16

The major/minor version (1, 1)

pub fn ascender(&self) -> FWord

Typographic ascent.

pub fn descender(&self) -> FWord

Typographic descent.

pub fn line_gap(&self) -> FWord

Typographic line gap. Negative LineGap values are treated as zero in some legacy platform implementations.

pub fn advance_height_max(&self) -> UfWord

Maximum advance height value in ‘vmtx’ table.

pub fn min_top_side_bearing(&self) -> FWord

Minimum top sidebearing value in ‘vmtx’ table for glyphs with contours (empty glyphs should be ignored).

pub fn min_bottom_side_bearing(&self) -> FWord

Minimum bottom sidebearing value

pub fn y_max_extent(&self) -> FWord

Defined as max( tsb + (yMax-yMin)).

pub fn caret_slope_rise(&self) -> i16

Used to calculate the slope of the cursor (rise/run); 1 for vertical caret, 0 for horizontal.

pub fn caret_slope_run(&self) -> i16

0 for vertical caret, 1 for horizontal.

pub fn caret_offset(&self) -> i16

The amount by which a slanted highlight on a glyph needs to be shifted to produce the best appearance. Set to 0 for non-slanted fonts

pub fn metric_data_format(&self) -> i16

0 for current format.

pub fn number_of_long_ver_metrics(&self) -> u16

Number of advance heights in the vertical metrics (vmtx) table.

pub fn version_byte_range(&self) -> Range<usize>

pub fn ascender_byte_range(&self) -> Range<usize>

pub fn descender_byte_range(&self) -> Range<usize>

pub fn line_gap_byte_range(&self) -> Range<usize>

pub fn advance_height_max_byte_range(&self) -> Range<usize>

pub fn min_top_side_bearing_byte_range(&self) -> Range<usize>

pub fn min_bottom_side_bearing_byte_range(&self) -> Range<usize>

pub fn y_max_extent_byte_range(&self) -> Range<usize>

pub fn caret_slope_rise_byte_range(&self) -> Range<usize>

pub fn caret_slope_run_byte_range(&self) -> Range<usize>

pub fn caret_offset_byte_range(&self) -> Range<usize>

pub fn reserved1_byte_range(&self) -> Range<usize>

pub fn reserved2_byte_range(&self) -> Range<usize>

pub fn reserved3_byte_range(&self) -> Range<usize>

pub fn reserved4_byte_range(&self) -> Range<usize>

pub fn metric_data_format_byte_range(&self) -> Range<usize>

pub fn number_of_long_ver_metrics_byte_range(&self) -> Range<usize>